import { PageHeading } from "@src/components/common/headings/pageHeading";
import { TodoList } from "@src/components/todos";
import { ProjectsHeading } from "@src/components/common/headings/projectsHeading";
import { groupByProjects } from "@src/core/actions/utility/groupByProjects";
import { todosApi } from "@src/infrastructure/apis/todosApi";
import { AddTodo } from "@src/components/todos/addTodo";
import { useMemo, useState } from "react";

function Inbox(props: { groupedTodos: any }) {
  const [folded, setFolded] = useState(false);

  return (
    <div className="space-y-2">
      <PageHeading
        title="Inbox"
        onClick={() => setFolded((folded) => !folded)}
      />
      <TodoList
        todos={props.groupedTodos["inbox"]}
        hideDone
        project={""}
        hideProject={false}
        folded={folded}
      />
    </div>
  );
}

function ProjectItem(props: { title: string; groupedTodos: any }) {
  const [folded, setFolded] = useState(false);
  return (
    <div className="space-y-2">
      <ProjectsHeading
        title={props.title}
        onClick={() => setFolded((folded) => !folded)}
      />
      <TodoList
        todos={props.groupedTodos[props.title]}
        hideDone
        project={props.title}
        hideProject
        folded={folded}
      />
    </div>
  );
}

const HomePage = () => {
  const { data, isLoading } = todosApi.useGetActiveTodosQuery();

  const onlyActiveTodos = useMemo(
    () => data?.filter((t) => t.status === false),
    [data]
  );
  const groupedTodos = useMemo(
    () => groupByProjects(onlyActiveTodos),
    [onlyActiveTodos]
  );
  const sections = useMemo(
    () =>
      Object.keys(groupedTodos)
        .filter((s) => s !== "inbox")
        .sort(),
    [groupedTodos]
  );

  if (isLoading) {
    return "loading...";
  }

  return (
    <main className="py-8 px-14 space-y-6">
      <section className="space-y-8 mx-auto max-w-4xl">
        {groupedTodos["inbox"] && <Inbox groupedTodos={groupedTodos} />}
        {sections &&
          sections.map((section) => (
            <ProjectItem
              key={section}
              title={section}
              groupedTodos={groupedTodos}
            />
          ))}
        {onlyActiveTodos && onlyActiveTodos.length === 0 && (
          <div className="space-y-4">
            <PageHeading title="You're done!" />
            <AddTodo project={""} />
          </div>
        )}
      </section>
    </main>
  );
};
export default HomePage;
